/*==================================================================
Projet: PPE Robot suiveur de ligne
Nom du fichier: MrLineTiny.h
Rle: Fichier d'en tte de la librairie MrLineTiny.lib
Cr le : 25/12/2010
Dernire rvision le :
Auteur: Philippe MARIANO
--------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08a
Composant cible : Atmel Atiny26
--------------------------------------------------------------
Cible Hardware  : Robot MrLineTiny
--------------------------------------------------------------
Remarque: Ce fichier est destin  un projet CVAVR V2 utilisant le
Robot MrLineTiny. Il doit tre plac dans le rpertoire du projet
===================================================================*/

#ifndef _MrLineTiny_INCLUDED
#define _MrLineTiny_INCLUDED

//=====================================================================================================
// Dclarations
//-----------------------------------------------------------------------------------------------------
// Boolen
//-----------------------------------------------------------------------------------------------------
#pragma warn- 
#define ACO     ACSR.5          // Redfinition de la sortie du comparateur analogique  
#pragma warn+
//----------------------------------------------------------------------------------------------------- 		
// Commande des moteurs  
//----------------------------------------------------------------------------------------------------- 
#define CDE_ROUE_G	OCR1A       //   Rglage de la frquence de rotation de la roue gauche
#define CDE_ROUE_D	OCR1B	    //   Rglage de la frquence de rotation de la roue droite
//-----------------------------------------------------------------------------------------------------
// Temporisations
//----------------------------------------------------------------------------------------------------- 
#define t_IR 	19 	            // Dure de la commande d'un metteur IR en s(Del IR) 
#define t_mux 	540    	        // Dure entre deux cde d'un metteur IR en s
//=====================================================================================================
// Variables globales 
//-----------------------------------------------------------------------------------------------------
// type		nom		Commentaires
//----------------------------------------------------------------------------------------------------- 
// Liste des diffrentes commandes des moteurs
enum Etat_Commande_Moteur {DEPART, CDE_CENTRE1, CDE_CENTRE2, CDE_CENTRE3, 
CDE_DROITE, CDE_DROITE_PLUS,  CDE_DROITE_2PLUS, CDE_GAUCHE, CDE_GAUCHE_PLUS,  CDE_GAUCHE_2PLUS};
//-----------------------------------------------------------------------------------------------------
// Liste des diffrentes positions du robot par rapport  la ligne 
enum Etat_Position_Robot {HORS_LIGNE, GAUCHE_PLUS , CENTRE_1, GAUCHE, 
DROITE_PLUS, CENTRE_2, DROITE, CENTRE_3}; 
//-----------------------------------------------------------------------------------------------------
//=====================================================================================================

//=====================================================================================================
// Prototype des fonctions de la bibliothque MrLineTiny
//-----------------------------------------------------------------------------------------------------
void Arret_Moteurs();
//=====================================================================================================
void Active_Timer();
//=====================================================================================================
unsigned char AcquerirPositionRobot(void);
//-----------------------------------------------------------------------------------------------------
/*  AcquerirPositionRobot = FS11 "Calculer la position du robot par rapport  la ligne" 
//-----------------------------------------------------------------------------------------------------
Rle : Etablir une valeur numrique reprsentative de la position du robot par rapport  la ligne
 
Entre(s):          ACO                     bit associ  la sortie du comparateur analogique, 
                                            reprsentatif de la position d'un capteur sur la ligne 
                    
Sortie(s):          Position_Robot          octet image de la position du robot par rapport  la ligne)
                                            (dtails ci-dessous)
                                        
Position des capteurs IR  =>  "Position_Robot"    // Positions du robot par rapport  la ligne
//-----------------------------------------------------------------------------------------------------
IR_G | IR_C  |  IR_D     =>     Position_Robot(10)
non  |  non  |   non     =>       0    // Hors ligne
non  |  non  |   oui     =>       1    // Gauche+
non  |  oui  |   non     =>       2    // Centre1 (ligne noire de largeur gale  celle d'un capteur)
non  |  oui  |   oui     =>       3    // Gauche
oui  |  non  |   non     =>       4    // Droite+
oui  |  non  |   oui     =>       5    // Centre2 (ligne blanche entoure de deux noires)
oui  |  oui  |   non     =>       6    // Droite
oui  |  oui  |   oui     =>       7    // Centre3 (ligne noire de largeur gale  celle de trois capteurs) 

                    Cde_Del_IR              octet permettant de multiplexer la commande des LED IR 
                                            Cde_Del_IR est recoupie dans le PORT A. Celui-ci commande 
                                            les LED IR (dtails ci-dessous)
                                            
                                            Emmetteur IR connect  au bit      Remarque 
                                            ----------------------------------------------------         
                                            E_D_IR        "      PA0    |       Emmeteur IR droit       
                                            E_C_IR        "      PA1    |       Emmeteur IR centre      
                                            E_G_IR        "      PA2    |       Emmeteur IR gauche                                                                   
-----------------------------------------------------------------------------------------------------*/
//=====================================================================================================
unsigned char AfficherPositionRobot(unsigned char Position_Robot);
//-----------------------------------------------------------------------------------------------------
/* AfficherPositionRobot = FS13 : " Choisir la valeur  afficher "
//-----------------------------------------------------------------------------------------------------
Rle :  Commande la LED correspondant au capteur sur la ligne

Entre(s):      Position_Robot      	(voir ci-dessus)

Sortie(s):	    VisuPosition            Octet non sign reprsentatif  de la position du robot 
                                        par rapport  la ligne
 					                    Led de visualisation connecte au bit
					                    ----------------------------------------
					                                Del_D       "      		PA3      
					                                Del_C       "	  		PA4
					                                Del_G       "	  		PA5 
					                    Remarque : D pour droite, C pour centre, G pour gauche
-----------------------------------------------------------------------------------------------------*/
//=====================================================================================================
void ReglerCdeMoteursRobot (unsigned char Position_Robot);
//-----------------------------------------------------------------------------------------------------
/* ReglerCdeMoteursRobot = FS12 : "Choisir les valeurs des rapports cycliques"
//-----------------------------------------------------------------------------------------------------
Rle: Rgler le rapport cyclique des signaux de commande des moteurs droit et gauche pour corriger la 
trajectoire du robot afin qu'il suive la ligne.

Entre(s):      Position_Robot       (voir ci-dessus)    

Sortie(s):      CDE_ROUE_G           octet	    (OCR1A) rgle le rapport cyclique du signal de commande  
					                            du moteur associ  la roue Gauche
	            CDE_ROUE_D           octet      (OCR1B) rgle le rapport cyclique du signal de commande  
	                                            du moteur associ  la roue Droite
-----------------------------------------------------------------------------------------------------*/  
//=====================================================================================================

#pragma library MrLineTiny.lib

#endif
